run

Function run 

pub fn run(args: &DoctorProcessesArgs) -> Result<()>
List registered server records and optionally remove stale records.

Errors

Returns an error if the registry cannot be read, a record cannot be parsed, or a requested stale-record cleanup cannot remove its file.