pub struct RuntimeFailure {
pub reason: String,
pub retryable: bool,
pub project_root: String,
pub session_id: String,
pub worker_generation: u64,
pub worker_restarted: bool,
pub restart_cause: Option<String>,
pub rss_kib: Option<u64>,
pub limit_kib: Option<u64>,
pub retry_after_millis: Option<u64>,
pub restarts_in_window: Option<u64>,
pub window_millis: Option<u64>,
}Fields
reason: Stringretryable: boolproject_root: Stringsession_id: Stringworker_generation: u64worker_restarted: boolrestart_cause: Option<String>rss_kib: Option<u64>limit_kib: Option<u64>retry_after_millis: Option<u64>restarts_in_window: Option<u64>window_millis: Option<u64>Trait Implementations
Sourceimpl Clone for RuntimeFailure
impl Clone for RuntimeFailure
Sourcefn clone(&self) -> RuntimeFailure
fn clone(&self) -> RuntimeFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeFailure
impl Debug for RuntimeFailure
Sourceimpl JsonSchema for RuntimeFailure
impl JsonSchema for RuntimeFailure
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuntimeFailure
impl RefUnwindSafe for RuntimeFailure
impl Send for RuntimeFailure
impl Sync for RuntimeFailure
impl Unpin for RuntimeFailure
impl UnsafeUnpin for RuntimeFailure
impl UnwindSafe for RuntimeFailure