pub struct DeclarationFlags {
pub is_private: bool,
pub is_generated: bool,
pub is_internal: bool,
}Fields
is_private: boolis_generated: boolis_internal: boolTrait Implementations
Sourceimpl Clone for DeclarationFlags
impl Clone for DeclarationFlags
Sourcefn clone(&self) -> DeclarationFlags
fn clone(&self) -> DeclarationFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeclarationFlags
impl Debug for DeclarationFlags
Sourceimpl JsonSchema for DeclarationFlags
impl JsonSchema for DeclarationFlags
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeclarationFlags
impl RefUnwindSafe for DeclarationFlags
impl Send for DeclarationFlags
impl Sync for DeclarationFlags
impl Unpin for DeclarationFlags
impl UnsafeUnpin for DeclarationFlags
impl UnwindSafe for DeclarationFlags