pub struct DeclarationInspection {
pub name: String,
pub kind: String,
pub module: Option<String>,
pub source: Option<SourceRange>,
pub statement: Option<RenderedText>,
pub statement_rendering: Option<String>,
pub docstring: Option<RenderedText>,
pub attributes: Vec<String>,
pub proof_search: DeclarationProofSearchFacts,
pub flags: DeclarationFlags,
}Fields
name: Stringkind: Stringmodule: Option<String>source: Option<SourceRange>statement: Option<RenderedText>statement_rendering: Option<String>How statement was rendered: "pretty" (notation-aware) or "raw"
(fully-elaborated Expr.toString). "raw" when Pretty was requested
but the pretty-printer could not render the term and fell back. None
when no statement was requested.
docstring: Option<RenderedText>attributes: Vec<String>proof_search: DeclarationProofSearchFactsflags: DeclarationFlagsTrait Implementations
Sourceimpl Clone for DeclarationInspection
impl Clone for DeclarationInspection
Sourcefn clone(&self) -> DeclarationInspection
fn clone(&self) -> DeclarationInspection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeclarationInspection
impl Debug for DeclarationInspection
Sourceimpl JsonSchema for DeclarationInspection
impl JsonSchema for DeclarationInspection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeclarationInspection
impl RefUnwindSafe for DeclarationInspection
impl Send for DeclarationInspection
impl Sync for DeclarationInspection
impl Unpin for DeclarationInspection
impl UnsafeUnpin for DeclarationInspection
impl UnwindSafe for DeclarationInspection