pub struct DeclarationRow {
pub name: String,
pub kind: String,
pub type_signature: Option<String>,
pub source: Option<SourceRange>,
}Fields
name: Stringkind: Stringtype_signature: Option<String>Pretty-printed type signature as the worker’s
LeanWorkerDeclarationRow reports it. None only when the
declaration has no recoverable type (typically internal artifacts).
source: Option<SourceRange>Trait Implementations
Sourceimpl Clone for DeclarationRow
impl Clone for DeclarationRow
Sourcefn clone(&self) -> DeclarationRow
fn clone(&self) -> DeclarationRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeclarationRow
impl Debug for DeclarationRow
Sourceimpl JsonSchema for DeclarationRow
impl JsonSchema for DeclarationRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeclarationRow
impl RefUnwindSafe for DeclarationRow
impl Send for DeclarationRow
impl Sync for DeclarationRow
impl Unpin for DeclarationRow
impl UnsafeUnpin for DeclarationRow
impl UnwindSafe for DeclarationRow