pub struct DeclarationSearchTimings {
pub scan_micros: u64,
pub rank_micros: u64,
pub source_micros: u64,
}Fields
scan_micros: u64rank_micros: u64source_micros: u64Trait Implementations
Sourceimpl Clone for DeclarationSearchTimings
impl Clone for DeclarationSearchTimings
Sourcefn clone(&self) -> DeclarationSearchTimings
fn clone(&self) -> DeclarationSearchTimings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeclarationSearchTimings
impl Debug for DeclarationSearchTimings
Sourceimpl JsonSchema for DeclarationSearchTimings
impl JsonSchema for DeclarationSearchTimings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeclarationSearchTimings
impl RefUnwindSafe for DeclarationSearchTimings
impl Send for DeclarationSearchTimings
impl Sync for DeclarationSearchTimings
impl Unpin for DeclarationSearchTimings
impl UnsafeUnpin for DeclarationSearchTimings
impl UnwindSafe for DeclarationSearchTimings