pub struct ModuleSourceSpan {
pub start_line: u32,
pub start_column: u32,
pub end_line: u32,
pub end_column: u32,
}Fields
start_line: u32start_column: u32end_line: u32end_column: u32Trait Implementations
Sourceimpl Clone for ModuleSourceSpan
impl Clone for ModuleSourceSpan
Sourcefn clone(&self) -> ModuleSourceSpan
fn clone(&self) -> ModuleSourceSpan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModuleSourceSpan
impl Debug for ModuleSourceSpan
Sourceimpl JsonSchema for ModuleSourceSpan
impl JsonSchema for ModuleSourceSpan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModuleSourceSpan
impl RefUnwindSafe for ModuleSourceSpan
impl Send for ModuleSourceSpan
impl Sync for ModuleSourceSpan
impl Unpin for ModuleSourceSpan
impl UnsafeUnpin for ModuleSourceSpan
impl UnwindSafe for ModuleSourceSpan