pub struct ProofActionDeclarationTarget {
pub short_name: String,
pub declaration_name: String,
pub namespace_name: String,
pub declaration_kind: String,
pub declaration_span: ModuleSourceSpan,
pub name_span: ModuleSourceSpan,
pub body_span: ModuleSourceSpan,
}Fields
short_name: Stringdeclaration_name: Stringnamespace_name: Stringdeclaration_kind: Stringdeclaration_span: ModuleSourceSpanname_span: ModuleSourceSpanbody_span: ModuleSourceSpanTrait Implementations
Sourceimpl Clone for ProofActionDeclarationTarget
impl Clone for ProofActionDeclarationTarget
Sourcefn clone(&self) -> ProofActionDeclarationTarget
fn clone(&self) -> ProofActionDeclarationTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProofActionDeclarationTarget
impl Debug for ProofActionDeclarationTarget
Sourceimpl JsonSchema for ProofActionDeclarationTarget
impl JsonSchema for ProofActionDeclarationTarget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProofActionDeclarationTarget
impl RefUnwindSafe for ProofActionDeclarationTarget
impl Send for ProofActionDeclarationTarget
impl Sync for ProofActionDeclarationTarget
impl Unpin for ProofActionDeclarationTarget
impl UnsafeUnpin for ProofActionDeclarationTarget
impl UnwindSafe for ProofActionDeclarationTarget