pub struct RenderedText {
pub value: String,
pub truncated: bool,
}Fields
value: Stringtruncated: boolTrait Implementations
Sourceimpl Clone for RenderedText
impl Clone for RenderedText
Sourcefn clone(&self) -> RenderedText
fn clone(&self) -> RenderedText
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderedText
impl Debug for RenderedText
Sourceimpl JsonSchema for RenderedText
impl JsonSchema for RenderedText
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RenderedText
impl RefUnwindSafe for RenderedText
impl Send for RenderedText
impl Sync for RenderedText
impl Unpin for RenderedText
impl UnsafeUnpin for RenderedText
impl UnwindSafe for RenderedText